<?php
namespace App\Http\Controllers;
use Auth;
use Carbon\Carbon;
use Carbon\CarbonPeriod;
use App\Models\Products;
use App\Models\User;
use App\Models\Visits;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use MikeMcLin\WpPassword\Facades\WpPassword;
use Illuminate\Support\Facades\Hash;

class ProductsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if (Auth::user()->usertype == 'admin' || Auth::user()->usertype == 'Admin'){
            $products = Products::all();
        }
        else{
            $products = Products::orderBy('name', 'asc')
            ->where([
                ['user_id', Auth::user()->id]
            ])->get();    
        }
        return view('admin.products.index',compact('products'));
    }

    public function active()
    {
        if (Auth::user()->usertype == 'admin' || Auth::user()->usertype == 'Admin'){
            $products = Products::orderBy('name', 'asc')
            ->where([
                //['user_id', Auth::user()->id],
                ['status', "Active"]
            ])->get();  
        }
        else{
            $products = Products::orderBy('name', 'asc')
            ->where([
                ['user_id', Auth::user()->id],
                ['status', "Active"]
            ])->get();    
        }
        return view('admin.products.active',compact('products'));
    }

    public function inactive()
    {
        if (Auth::user()->usertype == 'admin' || Auth::user()->usertype == 'Admin'){
            $products = Products::orderBy('name', 'asc')
            ->where([
              //  ['user_id', Auth::user()->id],
              ['status', '!=', 'active']
            ])->get();
        }
        else{
            $products = Products::orderBy('name', 'asc')
            ->where([
               // ['user_id', Auth::user()->id],
                ['status', '!=', 'active']
            ])->get();    
        }
        return view('admin.products.inactive',compact('products'));
    }

    public function status($id)
    {
        $product =  Products::find($id);
        return view('admin.products.status',compact('product'));
    }

    public function statusupdate(Request $request, $id)
    {
        $request->validate([
            'status' => 'required',
            
        ]);

        $products = Products::find($id);
        $products->status = $request->status;
        $products->save();

        return redirect()->back()
        ->with('success', 'Product status updated.');
    }


    public function dashboard()
    {
        $products = Products::all();
        $views = DB::table('visits')
            ->select(DB::raw('IFNULL(count(ipaddress), 0) as ipaddress,DATE(created_at) as mycreated_at'))
            ->groupBy('mycreated_at', 'ipaddress')
            ->get();
        $vendors = User::where([
                ['usertype', 'Vendor'],
                ['status','Active']
            ])->get();
        
        $now = Carbon::now();
        $monthback = Carbon::now()->subDays(30);
        $period = CarbonPeriod::create($monthback, $now);

        foreach($period as $date){
            $dates[] = $date->format('Y-m-d');
            $storeviews[] = DB::table('visits')
            ->select(DB::raw('IFNULL(count(ipaddress), 0) as ipaddress,DATE(created_at) as mycreated_at'))
            ->whereDate('created_at',  $date->format('Y-m-d'))
            ->groupBy('mycreated_at', 'ipaddress')
            ->pluck('ipaddress');
        }   
        
        return view('dashboard',compact('products','views','vendors', 'dates', 'storeviews'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
       /* 
        */
        if (Auth::user()->usertype == 'admin' || Auth::user()->usertype == 'Admin'){
            $vendors = User::inRandomOrder()
            ->where([
            //  ['status', 'active'], 
                ['usertype', 'Vendor']
            ])->get();
        }
        else{
            $vendors = User::orderBy('name', 'asc')
		->where([
           ['id', Auth::user()->id], 
        ])->get();
        }
        
        return view('admin.products.add_new',compact('vendors'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|max:255',
            'qty' => 'required',
            'description' => 'required',
            'image' => 'image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            'image2' => 'image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            'image3' => 'image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            'sector' => 'required',
            'tags' => 'required',
            'shipping' => 'required',
            'return' => 'required',
            'online' => 'required',
            'cod' => 'required',
            'vendor' => 'required',
            'sku' => 'required|unique:products|max:255',
            
        ]);
        //image 1
        if ($request->hasFile('image'))
        {
            $full_file_name = $request->file('image')->getClientOriginalName();
            $name = pathinfo($full_file_name, PATHINFO_FILENAME);
            $extension = $request->file('image')->getClientOriginalExtension();
            $file_name_to_store = $name.'_'.time().'.'.$extension;
            $path = $request->file('image')->storeAs('public/img/products', $file_name_to_store);
           
        }
        else
        {
            $file_name_to_store = '1.jpg';
        }
        //image 2
        if ($request->hasFile('image2'))
        {
            $full_file_name2 = $request->file('image2')->getClientOriginalName();
            $name2 = pathinfo($full_file_name2, PATHINFO_FILENAME);
            $extension2 = $request->file('image2')->getClientOriginalExtension();
            $file_name_to_store2 = $name2.'_'.time().'.'.$extension2;
            $path2 = $request->file('image2')->storeAs('public/img/products', $file_name_to_store2);
            
        }
        else
        {
            $file_name_to_store2 = '1.jpg';
        }
        //image 3
        if ($request->hasFile('image3'))
        {
            $full_file_name3 = $request->file('image3')->getClientOriginalName();
            $name3 = pathinfo($full_file_name3, PATHINFO_FILENAME);
            $extension3 = $request->file('image3')->getClientOriginalExtension();
            $file_name_to_store3 = $name3.'_'.time().'.'.$extension3;
            $path3 = $request->file('image3')->storeAs('public/img/products', $file_name_to_store3);
            
        }
        else
        {
            $file_name_to_store3 = '1.jpg';
        }

        
        $products = new products();
        $products->sku = $request->sku;
        $products->name = $request->name;
        $products->description = $request->description;
        $products->shipping = $request->shipping;
        $products->tags = $request->tags;
        $products->discount_id = $request->discount;
        $products->return = $request->return;
        $products->sector = $request->sector;
        $products->qty = $request->qty;
        $products->online = $request->online;
        $products->status = $request->status;
        $products->user_id = $request->vendor;
        $products->cod =$request->cod;
        $products->img_photo_path = $file_name_to_store;
        $products->img2_photo_path = $file_name_to_store2;
        $products->img3_photo_path = $file_name_to_store3;
        $products->save();

       // return redirect()->action([ProductsController::class, 'edit'], [$id])
       return redirect()->back()
        ->with('success', 'Product created successfully.');
    }

    public function images($id)
    {
        $product =  Products::find($id);
        return view('admin.products.change_image',compact('product'));
    }
    public function updateimages( Request $request)
    {
        $old = Products::find($request->id);
        $request->validate([
            'id' => 'required',
           // 'image' => 'image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            //'image2' => 'image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            //'image3' => 'image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            
        ]);
        //image 1
        if ($request->hasFile('image'))
        {
            $full_file_name = $request->file('image')->getClientOriginalName();
            $name = pathinfo($full_file_name, PATHINFO_FILENAME);
            $extension = $request->file('image')->getClientOriginalExtension();
            $file_name_to_store = $name.'_'.time().'.'.$extension;
            $path = $request->file('image')->storeAs('public/img/products', $file_name_to_store);
           
        }
        else
        {
            $file_name_to_store = $old->img_photo_path;
        }
        //image 2
        if ($request->hasFile('image2'))
        {
            $full_file_name2 = $request->file('image2')->getClientOriginalName();
            $name2 = pathinfo($full_file_name2, PATHINFO_FILENAME);
            $extension2 = $request->file('image2')->getClientOriginalExtension();
            $file_name_to_store2 = $name2.'_'.time().'.'.$extension2;
            $path2 = $request->file('image2')->storeAs('public/img/products', $file_name_to_store2);
            
        }
        else
        {
            $file_name_to_store2 = $old->img2_photo_path;;
        }
        //image 3
        if ($request->hasFile('image3'))
        {
            $full_file_name3 = $request->file('image3')->getClientOriginalName();
            $name3 = pathinfo($full_file_name3, PATHINFO_FILENAME);
            $extension3 = $request->file('image3')->getClientOriginalExtension();
            $file_name_to_store3 = $name3.'_'.time().'.'.$extension3;
            $path3 = $request->file('image3')->storeAs('public/img/products', $file_name_to_store3);
            
        }
        else
        {
            $file_name_to_store3 = $old->img3_photo_path;;
        }

        
        $products = Products::find($request->id);
        $products->img_photo_path = $file_name_to_store;
        $products->img2_photo_path = $file_name_to_store2;
        $products->img3_photo_path = $file_name_to_store3;
        $products->save();

       // return redirect()->action([ProductsController::class, 'edit'], [$id])
       return redirect()->back()
        ->with('success', 'Successfully updated images.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Products  $products
     * @return \Illuminate\Http\Response
     */
    public function show(Products $products)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Products  $products
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $product =  Products::find($id);
        $vendors = User::orderBy('name', 'asc')
		->where([
            ['usertype', 'Vendor']
        ])->get();
        return view('admin.products.edit',compact('product', 'vendors'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Products  $products
     * @return \Illuminate\Http\Response
     */
    public function productupdate(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|max:255',
            'qty' => 'required',
            'description' => 'required',
            'sector' => 'required',
            'tags' => 'required',
            'shipping' => 'required',
            'return' => 'required',
            'online' => 'required',
            'cod' => 'required',
            'vendor' => 'required',
            'sku' => 'required|max:255',
            
        ]);

        $products = Products::find($id);
        $products->sku = $request->sku;
        $products->name = $request->name;
        $products->description = $request->description;
        $products->shipping = $request->shipping;
        $products->tags = $request->tags;
        $products->discount_id = $request->discount;
        $products->return = $request->return;
        $products->sector = $request->sector;
        $products->qty = $request->qty;
        $products->online = $request->online;
        $products->status = $request->status;
        $products->user_id = $request->vendor;
        $products->cod =$request->cod;
        $products->save();

        return redirect()->back()
        ->with('success', 'Product successfully updated.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Products  $products
     * @return \Illuminate\Http\Response
     */
   
    public function destroys($id)
    {
        $product = Products::find($id);
        $product->delete();
        return redirect()->action([ProductsController::class, 'index'])
            ->with('success', 'Product deleted successfully,  Product name:  '  .$product->name);
    }
}
