<?php

namespace App\Providers;

use App\Actions\Fortify\CreateNewUser;
use App\Actions\Fortify\ResetUserPassword;
use App\Actions\Fortify\UpdateUserPassword;
use App\Actions\Fortify\UpdateUserProfileInformation;
use Illuminate\Cache\RateLimiting\Limit;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\RateLimiter;
use Illuminate\Support\ServiceProvider;
use Laravel\Fortify\Fortify;
use App\Listeners\WordPressPasswordUpdate;
use MikeMcLin\WpPassword\Facades\WpPassword;
use Illuminate\Auth\Events\Attempting;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use App\Models\User;

class FortifyServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        //
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        Fortify::createUsersUsing(CreateNewUser::class);
        Fortify::updateUserProfileInformationUsing(UpdateUserProfileInformation::class);
        Fortify::updateUserPasswordsUsing(UpdateUserPassword::class);
        Fortify::resetUserPasswordsUsing(ResetUserPassword::class);

        RateLimiter::for('login', function (Request $request) {
           $wp_hashed_password = User::where('email', $request->email)->first()->password ;
           $this->check($request->password, $wp_hashed_password ?? 'not found');
            return Limit::perMinute(5)->by($request->email.$request->ip());
        });

        RateLimiter::for('two-factor', function (Request $request) {
            return Limit::perMinute(5)->by($request->session()->get('login.id'));
        });

    
    }
    public function check($value, $wp_hashed_password, array $options = [])
        {
            if (Hash::needsRehash($wp_hashed_password)) 
            {
                if (WpPassword::check($value, $wp_hashed_password)) 
                {
                    $newHashedValue = (new \Illuminate\Hashing\BcryptHasher)->make($value, $options);
                    DB::update('UPDATE users SET `password` = "' . $newHashedValue . '" WHERE `password` = "' . $wp_hashed_password . '"');
                    $wp_hashed_password = $newHashedValue;
                }
            }
        }
}
