<?php
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\WelcomeController;
use App\Http\Controllers\ProductsController;
use App\Http\Controllers\SpecsController;
use App\Http\Controllers\VisitsController;
use App\Http\Controllers\VendorsController;
use App\Http\Controllers\ReviewsController;

/*COMPOSER_MEMORY_LIMIT=-1 composer update */
Route::get('/foo', function () {
    $exitCode = Artisan::call('storage:link');
    return '<h1>Storage link...</h1>';
});

Route::get('/', [WelcomeController::class, 'index'] )->name('welcome');
Route::get('/view-vendors/{sector}', [WelcomeController::class, 'vendors'])->name('view-vendors');
Route::get('/visit-store/{id}', [WelcomeController::class, 'visitstore'])->name('visit-store');
Route::get('/view-sectors', [WelcomeController::class, 'sectors'])->name('view-sectors');
Route::get('/view-products/{sector}', [WelcomeController::class, 'products'])->name('view-products');
Route::get('/product-detail/{id}', [WelcomeController::class, 'productdetail'])->name('product-detail');
Route::get('/contact-us', [WelcomeController::class,'contactus'])->name('contact-us');
Route::get('/become-a-vendor', [WelcomeController::class,'becomeavendor'])->name('become-a-vendor');
Route::get('/about-us', [WelcomeController::class,'aboutus'])->name('about-us');
Route::get('/blog',  [WelcomeController::class,'blog'])->name('blog');
Route::get('/single-blog/{id}',  [WelcomeController::class,'singleblog'])->name('single-blog');
Route::get('/faq',  [WelcomeController::class,'faq']);
Route::get('/newsletter',  [WelcomeController::class,'newsletter']);
Route::post('/view-products/results', [WelcomeController::class, 'search'] )->name('search');
Route::post('/newsletter', [WelcomeController::class, 'newsletter'] )->name('newsletter');




//admin
Route::resource('landing', WelcomeController::class);
Route::resource('products', ProductsController::class)->middleware(['auth:sanctum', 'verified']);
Route::resource('specs', SpecsController::class)->middleware(['auth:sanctum', 'verified']);
Route::resource('vendors', VendorsController::class)->middleware(['auth:sanctum', 'verified']);


Route::middleware(['auth:sanctum', 'verified'])
->get('/dashboard', [ProductsController::class, 'dashboard'] )->name('dashboard');

Route::middleware(['auth:sanctum', 'verified'])
->get('/list-products', [ProductsController::class, 'index'] )->name('list-products');

Route::middleware(['auth:sanctum', 'verified'])
->get('/add-product', [ProductsController::class, 'create'] )->name('add-product');

Route::middleware(['auth:sanctum', 'verified'])
->get('/active-products', [ProductsController::class, 'active'] )->name('active-products');

Route::middleware(['auth:sanctum', 'verified'])
->get('/inactive-products', [ProductsController::class, 'inactive'] )->name('inactive-products');

Route::middleware(['auth:sanctum', 'verified'])
->get('/status-product/{id}/status', [ProductsController::class, 'status'] )->name('status-product');

Route::post('/product-update/{id}', [ProductsController::class, 'productupdate'] )
->middleware(['auth:sanctum', 'verified'])->name('product-update');

Route::post('/status-update/{id}', [ProductsController::class, 'statusupdate'] )
->middleware(['auth:sanctum', 'verified'])->name('status-update');

Route::get('/product/{id}/delete', [ProductsController::class, 'destroys'] )
->middleware(['auth:sanctum', 'verified'])->name('delete.product');

Route::get('/spec/{id}/delete', [SpecsController::class, 'destroys'] )
->middleware(['auth:sanctum', 'verified'])->name('delete.spec');

Route::middleware(['auth:sanctum', 'verified'])
->get('/product-specs/{id}', [SpecsController::class, 'index'] )->name('product-specs');

Route::get('/product/{id}/images', [ProductsController::class, 'images'] )
->middleware(['auth:sanctum', 'verified'])->name('product-images');

Route::post('/product-updateimages', [ProductsController::class, 'updateimages'] )
->middleware(['auth:sanctum', 'verified'])->name('product-updateimages');

Route::post('/vendor-updateimages', [VendorsController::class, 'updateimages'] )
->middleware(['auth:sanctum', 'verified'])->name('vendor-updateimages');

Route::get('/product/{id}/edit', [ProductsController::class, 'edit'] )
->middleware(['auth:sanctum', 'verified'])->name('product-edit');

Route::get('/vendor/{id}/edit', [VendorsController::class, 'edit'] )
->middleware(['auth:sanctum', 'verified'])->name('vendor-edit'); 

Route::get('/vendor/{id}/images', [VendorsController::class, 'images'] )
->middleware(['auth:sanctum', 'verified'])->name('vendor-images');

Route::middleware(['auth:sanctum', 'verified'])
->get('/list-vendors', [VendorsController::class, 'index'] )->name('list-vendors');

Route::middleware(['auth:sanctum', 'verified'])
->get('/active-exporters', [VendorsController::class, 'active'] )->name('active-exporters');

Route::middleware(['auth:sanctum', 'verified'])
->get('/inactive-exporters', [VendorsController::class, 'inactive'] )->name('inactive-exporters');

Route::middleware(['auth:sanctum', 'verified'])
->get('/status-exporter/{id}/status', [VendorsController::class, 'status'] )->name('vendor-status');

Route::post('/exporter-status-update/{id}', [VendorsController::class, 'statusupdate'] )
->middleware(['auth:sanctum', 'verified'])->name('exporter-status-update');

Route::middleware(['auth:sanctum', 'verified'])
->get('/add-vendor', [VendorsController::class, 'create'] )->name('add-vendor');

Route::get('/vendor/{id}/delete', [VendorsController::class, 'destroys'] )
->middleware(['auth:sanctum', 'verified'])->name('delete.vendor');

Route::post('/vendor-update/{id}', [VendorsController::class, 'vendorupdate'] )
->middleware(['auth:sanctum', 'verified'])->name('vendor-update');

Route::post('/my-profile', [VendorsController::class, 'updates'] )
->middleware(['auth:sanctum', 'verified'])->name('my-profile');

Route::middleware(['auth:sanctum', 'verified'])
->get('/company-info', [VendorsController::class, 'company'] )->name('company-info');

Route::middleware(['auth:sanctum', 'verified'])
->get('/page-visits', [VisitsController::class, 'index'] )->name('page-visits');

Route::get('file-download/{pdf_path}',  [FileDownloadController::class, 'index'])
->middleware(['auth:sanctum', 'verified','role:student,tutor,admin'])->name('file-download');